@@ -110,6 +110,9 @@ class FeatureDescriptor(FrozenClass):
         self.window = parse_time_arg(window) if isinstance(window, str) else window
         self.stride = parse_time_arg(stride) if isinstance(stride, str) else stride
 
+        # from copy import deepcopy
+        # function = deepcopy(function)
+
         # Verify whether window and stride are either both sequence or time based
         dtype_set = set(
             AttributeParser.determine_type(v) for v in [self.window, self.stride]
@@ -233,6 +236,9 @@ class MultipleFeatureDescriptors:
         # Iterate over all combinations
         combinations = [functions, series_names, windows, strides]
         for function, series_name, window, stride in itertools.product(*combinations):
+            from copy import deepcopy
+            print(function.func)
+            function.func = deepcopy(function.func)
             self.feature_descriptions.append(
                 FeatureDescriptor(function, series_name, window, stride)
             )
