@@ -322,6 +322,61 @@ def catch22_wrapper(catch22_all: Callable) -> FuncWrapper:
 
 
 # ----------------------------------- TRANSFORMER -----------------------------------
+from .utils import _get_funcwrapper_func_and_kwargs
+# class WrappedTransformer:
+    
+#     def __init__(self, transformer):
+#         self.transformer = transformer
+#         self.__name__ = "[wrapped_transformer]__" + transformer.__repr__()
+
+#     def __call__(self, X):
+#         # if transformer.is_fitted:
+#         try:
+#             return self.transformer.transform(X)
+#         except:
+#             print("fit_transform ")
+#             # transformer = transformer.fit(X)
+#             return self.transformer.fit_transform(X)
+
+#     def __deepcopy__(self, memo):
+#         cls = self.transformer.__class__
+#         result = cls.__new__(cls)
+#         memo[id(self.transformer)] = result
+#         from copy import deepcopy
+#         # result.__dict__.update(copy(self.transformer.__dict__))
+#         for k, v in self.transformer.__dict__.items():
+#             setattr(result, k, deepcopy(v, memo))
+#         print(result)
+#         return WrappedTransformer(result)
+
+#     # def __deepcopy__(self, memo):
+#     #     cls = self.__class__
+#     #     result = cls.__new__(cls)
+#     #     memo[id(self)] = result
+#     #     for k, v in self.__dict__.items():
+#     #         setattr(result, k, deepcopy(v, memo))
+#     #     return result
+        
+
+# def transformer_wrapper(transformer) -> FuncWrapper:
+#     from sklearn.base import TransformerMixin
+#     # assert isinstance(transformer, FuncWrapper) or isinstance(transformer, TransformerMixin)
+    
+#     func_wrapper_kwargs = {}
+#     if isinstance(transformer, FuncWrapper):
+#         # Extract the function and keyword arguments from the function wrapper
+#         transformer, func_wrapper_kwargs = _get_funcwrapper_func_and_kwargs(transformer)
+
+#     assert hasattr(transformer, "fit_transform")# and hasattr(transformer, "transform")
+
+#     func_wrapper_kwargs["vectorized"] = True
+    
+#     # from copy import copy
+
+#     wrapped_transformer = WrappedTransformer(transformer)
+#     # wrapped_transformer.__name__ = "[wrapped_transformer]__" + transformer.__repr__()
+#     return FuncWrapper(wrapped_transformer, **func_wrapper_kwargs)
+
 from .utils import _get_funcwrapper_func_and_kwargs
 def transformer_wrapper(transformer) -> FuncWrapper:
     from sklearn.base import TransformerMixin
@@ -332,18 +387,17 @@ def transformer_wrapper(transformer) -> FuncWrapper:
         # Extract the function and keyword arguments from the function wrapper
         transformer, func_wrapper_kwargs = _get_funcwrapper_func_and_kwargs(transformer)
 
-    assert hasattr(transformer, "fit_transform")# and hasattr(transformer, "transform")
+    assert hasattr(transformer, "fit") and hasattr(transformer, "transform")
 
     func_wrapper_kwargs["vectorized"] = True
     
     def wrap_transformer(X):
-        # if transformer.is_fitted:
         try:
-            print("tranform")
             return transformer.transform(X)
         except:
-            print("fit_transform")
+            # print("Fitting")
             return transformer.fit_transform(X)
 
-    wrap_transformer.__name__ = "[wrapped_transformer]__" + _get_name(transformer)
+    wrap_transformer.__name__ = "[wrapped_transformer]__" + transformer.__repr__()
     return FuncWrapper(wrap_transformer, **func_wrapper_kwargs)
+
